import { render } from '@testing-library/react';
import NuskinThemeProvider from './NuskinThemeProvider';
import { createTheme } from '@mui/material/styles';
import Button from '@mui/material/Button';

describe('NuskinThemeProvider', () => {
    const theme = createTheme({
        palette: {
            primary: {
                main: '#f00',
            },
        },
    });
    const commonText = 'Nu Skin App';
    it('renders without crashing', () => {
        const { getByText } = render(
            <NuskinThemeProvider theme={theme}>
                <div>{commonText}</div>
            </NuskinThemeProvider>,
        );
        expect(getByText(commonText)).toBeInTheDocument();
    });

    it('applies the correct theme to ThemeProvider', () => {
        const { getByText } = render(
            <NuskinThemeProvider theme={theme}>
                <Button variant="contained">{commonText}</Button>
            </NuskinThemeProvider>,
        );
        const comp = getByText(commonText);
        expect(comp).toHaveStyle('background-color: rgb(255, 0, 0)');
    });

    it('applies the correct theme to ThemeProvider with SSR', () => {
        const { getByText } = render(
            <NuskinThemeProvider theme={theme} isSSR>
                <Button variant="contained">{commonText}</Button>
            </NuskinThemeProvider>,
        );
        const comp = getByText(commonText);
        expect(comp).toHaveStyle('background-color: rgb(255, 0, 0)');
    });
});
/*
we could check that theme is available in the component
*/
