import { NextPageContext } from 'next';

import Button from '@mui/material/Button';

import { NuskinThemeProvider } from '../components';
import { nuskinThemeTitleStyle } from './theme-builder';
import { FoundationTheme } from '../themes/types';

type HomePageProps = {
    theme?: FoundationTheme.Theme;
    themeName: string;
};

const buttonStyle = {
    marginBottom: "10px",
    marginLeft: 150
};

export default function Home({ theme, themeName }: HomePageProps) {
    const { palette = {}} = theme || {};
    const colorVariables = Object.keys(palette) as FoundationTheme.PaletteColors[];

    return (
        <NuskinThemeProvider
            cacheKey="nuskin-foundation-ui"
            theme={theme}
            isSSR
        >
            <h2 style={nuskinThemeTitleStyle}>
                {themeName === 'force-for-good' ? 'Force-For-Good-Button-Theme' : 'Nuskin-Button-Theme'}
            </h2>
            {colorVariables?.map((color) => (
                <div style={buttonStyle} key={color}>
                    <Button variant="contained" color={color}>
                        nuskin button
                    </Button>
                </div>
            ))}
            <h1 className="bg-accentColorA-30 text-white">Configuring Tailwind</h1>
        </NuskinThemeProvider>
    );
}

Home.getInitialProps = async (ctx: NextPageContext) => {
    const { query, req } = ctx || {};
    const themeName = query?.theme || 'nuskin-theme';
    let response;
    try {
        /*
         * [Todo] - Determine the environment in which the theme has to fetch the json
         */
        let config = await fetch(`http://${req?.headers.host}/${themeName}.json`);
        response = await config.json();
    } catch {
        console.warn('Theme Not found');
    }
    return {
        theme: response,
        themeName
    };
};
