import { generateGlobalColorCss, generatePalette } from "../theme-utils";

const validTheme = {
    "palette": {
        "primary": {
            "main": "#252525",
            "contrastText": "#FFFFFF",
            "buttonState": {
                "hovered": "#8C8C8C",
                "disabled": "#E0E0E0",
                "pressed": "#F5F5F5",
                "focused": "#252525",
                "disabledText": "#8C8C8C"
            },
            "darkMode": {
                "main": "#F5F5F5",
                "contrastText": "#252525",
                "buttonState": {
                    "hovered": "#C66464",
                    "hoveredText": "#FFFFFF",
                    "pressed": "#A54553",
                    "pressedText": "#FFFFFF",
                    "focused": "#F5F5F5",
                    "disabled": "#5F5F5F"
                }
            }
        },
    },
};

describe('Theme Utils', () => {
    it('generatePalette to return light mode values', () => {
        const palette = generatePalette(validTheme.palette, false);
        expect(palette?.primary?.main).toBe("#252525");
    });
    
    it('generatePalette to return dark mode values', () => {
        const palette = generatePalette(validTheme.palette, true);
        expect(palette?.primary?.main).toBe("#F5F5F5");
    });

    it('generateGlobalColorCss to return the proper css string', () => {
        const cssString = generateGlobalColorCss(validTheme);
        expect(cssString).toContain(`.bg-primary`);
        expect(cssString).toContain(`.text-primary`);
        expect(cssString).toContain(`.border-primary`);
    });

    it('generateGlobalColorCss to return the proper css string', () => {
        const cssString = generateGlobalColorCss(validTheme);
        expect(cssString).toContain(`.bg-primary`);
        expect(cssString).toContain(`.text-primary`);
        expect(cssString).toContain(`.border-primary`);
    });

    it('generateGlobalColorCss to have the .dark class', () => {
        const theme = {
            ...validTheme,
            colors: {
                "accentColorA": {
                    main: "#F56767",
                    dark: "#FC9492"
                }
            },
        };
        const cssString = generateGlobalColorCss(theme);
        expect(cssString).toContain(`.dark {`);
    });

    it('generateGlobalColorCss to not have the .dark class', () => {
        const cssString = generateGlobalColorCss(validTheme);
        expect(cssString).not.toContain(`.dark {`);
    });
});